@@ -308,19 +308,13 @@
 \\partialJazzExceptions
 \\partial
 \\partcombineUp
-\\partcombineUnisonoOnce
 \\partcombineUnisono
-\\partcombineSoloIOnce
-\\partcombineSoloIIOnce
 \\partcombineSoloII
 \\partcombineSoloI
 \\partcombineForce
 \\partcombineDown
-\\partcombineChordsOnce
 \\partcombineChords
-\\partcombineAutomaticOnce
 \\partcombineAutomatic
-\\partcombineApartOnce
 \\partcombineApart
 \\partcombine
 \\partCombineTextsOnNote
